@@ -11,7 +11,7 @@ use MooseX::Types::Path::Class;
 use POE;
 with qw(MooseX::Log::Log4perl MooseX::Getopt);
 
-our $VERSION = '0.01008';
+our $VERSION = '0.01009';
 
 =head1 NAME
 
@@ -21,6 +21,7 @@ Gearman::Driver - Manages Gearman workers
 
     package My::Workers::One;
 
+    # Yes, you need to do it exactly this way
     use base qw(Gearman::Driver::Worker);
     use Moose;
 
@@ -161,7 +162,7 @@ has 'namespaces' => (
     handles       => { get_namespaces => 'sort' },
     is            => 'rw',
     isa           => 'ArrayRef[Str]',
-    required      => 1,
+    required      => 0,
     traits        => [qw(Array)],
 );
 
@@ -440,8 +441,126 @@ has '+logger' => ( traits => [qw(NoGetopt)] );
 
 =head1 METHODS
 
-Every method except L<run|/run> might only be interesting for
-people subclassing L<Gearman::Driver>.
+=head2 add_job
+
+There's one mandatory param (hashref) with following keys:
+
+=over 4
+
+=item * decode (optionally)
+
+Name of a decoder method in your worker object.
+
+=item * encode (optionally)
+
+Name of a encoder method in your worker object.
+
+=item * method (mandatory)
+
+Reference to a L<Class::MOP::Method> object which will get invoked.
+
+=item * min_childs (mandatory)
+
+Minimum number of childs that should be forked.
+
+=item * max_childs (mandatory)
+
+Maximum number of childs that may be forked.
+
+=item * name (mandatory)
+
+Job name/alias that method should be registered with Gearman.
+
+=item * object (mandatory)
+
+Object that should be passed as first parameter to the job method.
+
+=back
+
+Basically you never really need this method if you use
+L</namespaces>. But this depends on method attributes which some
+people do hate. In this case, feel free to setup Gearman::Driver
+this way:
+
+    package My::Workers::One;
+
+    use Moose;
+    use JSON::XS;
+    extends 'Gearman::Driver::Worker::Base';
+
+    sub scale_image {
+        my ( $self, $job, $workload ) = @_;
+        # do something
+    }
+
+    # this method will be registered with gearmand as 'My::Workers::One::do_something_else'
+    sub do_something_else {
+        my ( $self, $job, $workload ) = @_;
+        # do something
+    }
+
+    sub encode_json {
+        my ( $self, $result ) = @_;
+        return JSON::XS::encode_json($result);
+    }
+
+    sub decode_json {
+        my ( $self, $workload ) = @_;
+        return JSON::XS::decode_json($workload);
+    }
+
+    1;
+
+    package main;
+
+    use Gearman::Driver;
+    use My::Workers::One;
+
+    my $driver = Gearman::Driver->new(
+        server   => 'localhost:4730,otherhost:4731',
+        interval => 60,
+    );
+
+    my $worker = My::Workers::One->new();
+
+    foreach my $method (qw(scale_image do_something_else)) {
+        $driver->add_job(
+            decode     => 'decode_json',
+            encode     => 'encode_json',
+            max_childs => 5,
+            method     => $worker->meta->find_method_by_name($method)->body,
+            min_childs => 1,
+            name       => $method,
+            object     => $worker,
+        );
+    }
+
+    $driver->run;
+
+
+=cut
+
+sub add_job {
+    my ( $self, $params ) = @_;
+
+    my $job = Gearman::Driver::Job->new(
+        driver     => $self,
+        decode     => $params->{decode} || '',
+        encode     => $params->{encode} || '',
+        max_childs => $params->{max_childs},
+        method     => $params->{method},
+        min_childs => $params->{min_childs},
+        name       => $params->{name},
+        server     => $self->server,
+        worker     => $params->{object},
+    );
+
+    $self->_set_job( $params->{name} => $job );
+
+    $self->log->debug( sprintf "Added new job: %s (childs: %d)", $params->{name}, $params->{min_childs} );
+
+    return 1;
+}
 
 =head2 run
 
@@ -450,6 +569,11 @@ This must be called after the L<Gearman::Driver> object is instantiated.
 =cut
 
 sub run {
+    my ($self) = @_;
+    push @INC, @{ $self->lib };
+    $self->_load_namespaces;
+    $self->_start_observer;
+    $self->_start_session;
     POE::Kernel->run();
 }
 
@@ -481,16 +605,7 @@ Returns the job instance.
 
 sub BUILD {
     my ($self) = @_;
-    $self->_setup;
-}
-
-sub _setup {
-    my ($self) = @_;
-    push @INC, @{ $self->lib };
     $self->_setup_logger;
-    $self->_load_namespaces;
-    $self->_start_observer;
-    $self->_start_session;
 }
 
 sub _setup_logger {
@@ -521,21 +636,11 @@ sub _load_namespaces {
         $self->log->debug("Module found in namespace '$ns': $_") for @modules_ns;
     }
 
-    unless (@modules) {
-        my $ns = join ', ', $self->get_namespaces;
-        croak "Could not find any modules in those namespaces: $ns";
-    }
-
     foreach my $module (@modules) {
         next unless $self->_is_valid_worker_subclass($module);
         next unless $self->_has_job_method($module);
         $self->_add_module($module);
     }
-
-    unless ( $self->has_modules ) {
-        my $modules = join ', ', sort @modules;
-        croak "None of the modules have a method with 'Job' attribute set: $modules";
-    }
 }
 
 sub _is_valid_worker_subclass {
@@ -558,7 +663,7 @@ sub _has_job_method {
 
 sub _start_observer {
     my ($self) = @_;
-    if ($self->interval > 0) {
+    if ( $self->interval > 0 ) {
         $self->{observer} = Gearman::Driver::Observer->new(
             callback => sub {
                 my ($status) = @_;
@@ -629,34 +734,46 @@ sub _on_sig {
 
 sub _start {
     $_[KERNEL]->sig( $_ => 'got_sig' ) for qw(INT QUIT ABRT KILL TERM);
+    $_[OBJECT]->_add_jobs;
     $_[OBJECT]->_start_jobs;
 }
 
+sub _add_jobs {
+    my ($self) = @_;
+
+    foreach my $module ( $self->get_modules ) {
+        my $worker = $module->new( server => $self->server );
+
+        foreach my $method ( $module->meta->get_nearest_methods_with_attributes ) {
+            apply_all_roles( $method => 'Gearman::Driver::Worker::AttributeParser' );
+
+            $method->default_attributes( $worker->default_attributes );
+            $method->override_attributes( $worker->override_attributes );
+
+            next unless $method->has_attribute('Job');
+
+            $self->add_job(
+                {
+                    decode     => $method->get_attribute('Decode'),
+                    encode     => $method->get_attribute('Encode'),
+                    max_childs => $method->get_attribute('MaxChilds'),
+                    method     => $method->body,
+                    min_childs => $method->get_attribute('MinChilds'),
+                    name       => $worker->prefix . $method->name,
+                    object     => $worker,
+                }
+            );
+        }
+
+    }
+}
+
 sub _start_jobs {
     my ($self) = @_;
 
-    foreach my $module ( $self->get_modules ) {
-        my $worker = $module->new( server => $self->server );
-        foreach my $method ( $module->meta->get_nearest_methods_with_attributes ) {
-            apply_all_roles( $method => 'Gearman::Driver::Worker::AttributeParser' );
-            $method->default_attributes( $worker->default_attributes );
-            $method->override_attributes( $worker->override_attributes );
-            next unless $method->has_attribute('Job');
-            my $name = $worker->prefix . $method->name;
-            my $job  = Gearman::Driver::Job->new(
-                driver     => $self,
-                method     => $method,
-                name       => $name,
-                worker     => $worker,
-                server     => $self->server,
-                min_childs => $method->get_attribute('MinChilds'),
-                max_childs => $method->get_attribute('MaxChilds'),
-            );
-            for ( 1 .. $method->get_attribute('MinChilds') ) {
-                $job->add_child();
-            }
-            $self->_set_job( $name => $job );
-            $self->log->debug( sprintf "Added new job: $name (childs: %d)", $method->get_attribute('MinChilds') );
+    foreach my $job ( $self->get_jobs ) {
+        for ( 1 .. $job->min_childs ) {
+            $job->add_child();
         }
     }
 }
